@@ -40,7 +40,7 @@ pub fn fetch_symbols(exchange: &str, market_type: MarketType) -> Result<Vec<Stri
         "huobi" => exchanges::huobi::fetch_symbols(market_type),
         "kraken" => exchanges::kraken::fetch_symbols(market_type),
         "kucoin" => exchanges::kucoin::fetch_symbols(market_type),
-        "mxc" => exchanges::mxc::fetch_symbols(market_type),
+        "mexc" => exchanges::mexc::fetch_symbols(market_type),
         "okx" => exchanges::okx::fetch_symbols(market_type),
         "zbg" => exchanges::zbg::fetch_symbols(market_type),
         _ => panic!("Unsupported exchange {}", exchange),
@@ -81,7 +81,7 @@ pub fn fetch_markets(exchange: &str, market_type: MarketType) -> Result<Vec<Mark
         "huobi" => exchanges::huobi::fetch_markets(market_type),
         "kraken" => exchanges::kraken::fetch_markets(market_type),
         "kucoin" => exchanges::kucoin::fetch_markets(market_type),
-        "mxc" => exchanges::mxc::fetch_markets(market_type),
+        "mexc" => exchanges::mexc::fetch_markets(market_type),
         "okx" => exchanges::okx::fetch_markets(market_type),
         "zbg" => exchanges::zbg::fetch_markets(market_type),
         _ => panic!("Unsupported exchange {}", exchange),
